aboutsummaryrefslogtreecommitdiffhomepage
path: root/include
diff options
context:
space:
mode:
authorGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-11-29 18:58:19 +0000
committerGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-11-29 18:58:19 +0000
commit9128edc700ce1b722f1290c585af829542f98a33 (patch)
treefee8f6f487a611ca9b9c5606fa63b2d7ad97c0b2 /include
parent83a853aa65c9f380dbaa9637d9be1d676d1991ed (diff)
Rename SkClipStack::Rec to SkClipStack::Element
R=robertphillips@google.com Review URL: https://codereview.appspot.com/6854115 git-svn-id: http://skia.googlecode.com/svn/trunk@6605 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'include')
-rw-r--r--include/core/SkClipStack.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/core/SkClipStack.h b/include/core/SkClipStack.h
index f2c067e930..7b3078d8e4 100644
--- a/include/core/SkClipStack.h
+++ b/include/core/SkClipStack.h
@@ -112,7 +112,7 @@ public:
int32_t getTopmostGenID() const;
private:
- struct Rec;
+ struct Element;
public:
class Iter {
@@ -199,7 +199,7 @@ public:
* updateClip updates fClip to the current state of fIter. It unifies
* functionality needed by both next() and prev().
*/
- const Clip* updateClip(const SkClipStack::Rec* rec);
+ const Clip* updateClip(const SkClipStack::Element* element);
};
/**
@@ -278,9 +278,9 @@ private:
mutable SkTDArray<ClipCallbackData> fCallbackData;
/**
* Invoke all the purge callbacks passing in rec's generation ID.
*/
- void purgeClip(Rec* rec);
+ void purgeClip(Element* element);
/**
* Return the next unique generation ID.
@@ -278,9 +278,9 @@ private:
mutable SkTDArray<ClipCallbackData> fCallbackData;
/**
- * Invoke all the purge callbacks passing in rec's generation ID.
+ * Invoke all the purge callbacks passing in element's generation ID.
*/